@@ -104,5 +104,6 @@
 #' par <- list(sf = gsDesign::sfLDOF, total_spend = 0.2)
 #' gs_spending_combo(par, info = 1:3 / 3)
 gs_spending_combo <- function(par = NULL, info = NULL) {
-  par$sf(alpha = par$total_spend, t = info, param = par$param)$spend
+  sf <- get_sf(par$sf)
+  sf(alpha = par$total_spend, t = info, param = par$param)$spend
 }
